# API Reference

This page provides an auto-generated summary of xcollection’s API.
For more details and examples, refer to the relevant chapters in the main part of the documentation.

```{toctree}
---
maxdepth: 2
caption: Reference
---
main.md
```
